PAWpySeed: pawpyseed.core.symmetry Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Functions
pawpyseed.core.symmetry Namespace Reference

## Functions
def | get_symmops (structure, symprec)
def | get_nosym_kpoints (kpts, structure, init_kpts=None, symprec=1e-5, gen_trsym=True, fil_trsym=True)
def | get_kpt_mapping (allkpts, kpts, structure, symprec=1e-5, gen_trsym=True)

## Function Documentation

def pawpyseed.core.symmetry.get_kpt_mapping | ( |  | allkpts,
|  |  | kpts,
|  |  | structure,
|  |  | symprec = `1e-5`,
|  |  | gen_trsym = `True`
| ) |  |

def pawpyseed.core.symmetry.get_nosym_kpoints | ( |  | kpts,
|  |  | structure,
|  |  | init_kpts = `None`,
|  |  | symprec = `1e-5`,
|  |  | gen_trsym = `True`,
|  |  | fil_trsym = `True`
| ) |  |

def pawpyseed.core.symmetry.get_symmops | ( |  | structure,
|  |  | symprec
| ) |  |